@@ -22,17 +22,14 @@
 
 #include <memory>
 #include <cmath>
+#include <string>
 
 namespace utility {
 
-template<typename T, typename... Args>
-std::unique_ptr<T> make_unique(Args&&... args) {
-    return std::unique_ptr<T>(new T(std::forward<Args>(args)...));
-}
-
 bool isEqualStr(std::string& str1, std::string str2);
 
 double similarityToDistance(const double distance);
+
 }
 
 #endif
